==> qtwebengine-everywhere-src-6.9.2.tar.xz: qtwebengine-everywhere-src-6.9.2/src/3rdparty/chromium/chrome/browser/resources/tab_search/tab_search.ts <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './app.js';

export {CrInputElement} from 'chrome://resources/cr_elements/cr_input/cr_input.js';
export {TabSearchAppElement} from './app.js';
export {AutoTabGroupsPageElement} from './auto_tab_groups/auto_tab_groups_page.js';
export {AutoTabGroupsResultsElement} from './auto_tab_groups/auto_tab_groups_results.js';
export {DeclutterPageElement} from './declutter/declutter_page.js';
export {LazyListElement} from './lazy_list.js';
export {search, SearchOptions} from './search.js';
export {SelectableLazyListElement} from './selectable_lazy_list.js';
export {getHostname, getTabGroupTitle, getTitle, ItemData, TabData, TabItemType} from './tab_data.js';
export {Color as TabGroupColor} from './tab_group_types.mojom-webui.js';
export {TabOrganizationSelectorElement} from './tab_organization_selector.js';
export {TabOrganizationSelectorButtonElement} from './tab_organization_selector_button.js';
export {PageCallbackRouter, PageRemote, ProfileData, RecentlyClosedTab, RecentlyClosedTabGroup, SwitchToTabInfo, Tab, TabGroup, TabOrganizationError, TabOrganizationModelStrategy, TabOrganizationSession, TabOrganizationState, TabsRemovedInfo, TabUpdateInfo, UserFeedback, Window} from './tab_search.mojom-webui.js';
export {TabSearchApiProxy, TabSearchApiProxyImpl} from './tab_search_api_proxy.js';
export {TabSearchGroupItemElement} from './tab_search_group_item.js';
export {TabSearchItemElement} from './tab_search_item.js';
export {TabSearchPageElement} from './tab_search_page.js';
export {TabSearchSyncBrowserProxy, TabSearchSyncBrowserProxyImpl} from './tab_search_sync_browser_proxy.js';
export {TabAlertState} from './tabs.mojom-webui.js';
export {TitleItem} from './title_item.js';

==> qtwebengine-everywhere-src-6.10.2.tar.xz: qtwebengine-everywhere-src-6.10.2/src/3rdparty/chromium/chrome/browser/resources/tab_search/tab_search.ts <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './app.js';

export {getInstance as getAnnouncerInstance, TIMEOUT_MS} from 'chrome://resources/cr_elements/cr_a11y_announcer/cr_a11y_announcer.js';
export {CrInputElement} from 'chrome://resources/cr_elements/cr_input/cr_input.js';
export {TabSearchAppElement} from './app.js';
export {AutoTabGroupsPageElement} from './auto_tab_groups/auto_tab_groups_page.js';
export {AutoTabGroupsResultsElement} from './auto_tab_groups/auto_tab_groups_results.js';
export {DeclutterPageElement} from './declutter/declutter_page.js';
export {LazyListElement} from './lazy_list.js';
export {search, SearchOptions} from './search.js';
export {SelectableLazyListElement} from './selectable_lazy_list.js';
export {getHostname, getTabGroupTitle, getTitle, ItemData, TabData, TabItemType} from './tab_data.js';
export {Color as TabGroupColor} from './tab_group_types.mojom-webui.js';
export {TabOrganizationSelectorElement} from './tab_organization_selector.js';
export {TabOrganizationSelectorButtonElement} from './tab_organization_selector_button.js';
export {PageCallbackRouter, PageRemote, ProfileData, RecentlyClosedTab, RecentlyClosedTabGroup, SwitchToTabInfo, Tab, TabGroup, TabOrganizationError, TabOrganizationFeature, TabOrganizationModelStrategy, TabOrganizationSession, TabOrganizationState, TabSearchSection, TabsRemovedInfo, TabUpdateInfo, UnusedTabInfo, UserFeedback, Window} from './tab_search.mojom-webui.js';
export {TabSearchApiProxy, TabSearchApiProxyImpl} from './tab_search_api_proxy.js';
export {TabSearchGroupItemElement} from './tab_search_group_item.js';
export {TabSearchItemElement} from './tab_search_item.js';
export {TabSearchPageElement} from './tab_search_page.js';
export {TabSearchSyncBrowserProxy, TabSearchSyncBrowserProxyImpl} from './tab_search_sync_browser_proxy.js';
export {TabAlertState} from './tabs.mojom-webui.js';
export {TitleItem} from './title_item.js';
